[Python-checkins] cpython: Rename test_pep####.py files

zach.ware python-checkins at python.org
Fri Sep 9 15:55:56 EDT 2016


https://hg.python.org/cpython/rev/7464142fc867
changeset:   103453:7464142fc867
user:        Zachary Ware <zachary.ware at gmail.com>
date:        Fri Sep 09 12:55:37 2016 -0700
summary:
  Rename test_pep####.py files

files:
  Lib/test/test_baseexception.py          |   0 
  Lib/test/test_dict_version.py           |   0 
  Lib/test/test_exception_hierarchy.py    |   0 
  Lib/test/test_generator_stop.py         |   0 
  Lib/test/test_tokenize.py               |  11 ++++++-----
  Lib/test/test_unicode_file_functions.py |   0 
  Lib/test/test_unicode_identifiers.py    |   0 
  Lib/test/test_utf8source.py             |   0 
  Lib/test/test_yield_from.py             |   0 
  9 files changed, 6 insertions(+), 5 deletions(-)


diff --git a/Lib/test/test_pep352.py b/Lib/test/test_baseexception.py
rename from Lib/test/test_pep352.py
rename to Lib/test/test_baseexception.py
diff --git a/Lib/test/test_pep509.py b/Lib/test/test_dict_version.py
rename from Lib/test/test_pep509.py
rename to Lib/test/test_dict_version.py
diff --git a/Lib/test/test_pep3151.py b/Lib/test/test_exception_hierarchy.py
rename from Lib/test/test_pep3151.py
rename to Lib/test/test_exception_hierarchy.py
diff --git a/Lib/test/test_pep479.py b/Lib/test/test_generator_stop.py
rename from Lib/test/test_pep479.py
rename to Lib/test/test_generator_stop.py
diff --git a/Lib/test/test_tokenize.py b/Lib/test/test_tokenize.py
--- a/Lib/test/test_tokenize.py
+++ b/Lib/test/test_tokenize.py
@@ -1529,12 +1529,13 @@
         tempdir = os.path.dirname(fn) or os.curdir
         testfiles = glob.glob(os.path.join(tempdir, "test*.py"))
 
         # Tokenize is broken on test_pep3131.py because regular expressions are
         # broken on the obscure unicode identifiers in it. *sigh*
         # With roundtrip extended to test the 5-tuple mode of  untokenize,
         # 7 more testfiles fail.  Remove them also until the failure is diagnosed.
 
-        testfiles.remove(os.path.join(tempdir, "test_pep3131.py"))
+        testfiles.remove(os.path.join(tempdir, "test_unicode_identifiers.py"))
         for f in ('buffer', 'builtin', 'fileio', 'inspect', 'os', 'platform', 'sys'):
             testfiles.remove(os.path.join(tempdir, "test_%s.py") % f)
 
@@ -1529,12 +1529,13 @@
         testfiles = glob.glob(os.path.join(tempdir, "test*.py"))
 
-        # Tokenize is broken on test_pep3131.py because regular expressions are
-        # broken on the obscure unicode identifiers in it. *sigh*
-        # With roundtrip extended to test the 5-tuple mode of  untokenize,
-        # 7 more testfiles fail.  Remove them also until the failure is diagnosed.
+        # Tokenize is broken on test_unicode_identifiers.py because regular
+        # expressions are broken on the obscure unicode identifiers in it.
+        # *sigh* With roundtrip extended to test the 5-tuple mode of
+        # untokenize, 7 more testfiles fail.  Remove them also until the
+        # failure is diagnosed.
 
diff --git a/Lib/test/test_pep277.py b/Lib/test/test_unicode_file_functions.py
rename from Lib/test/test_pep277.py
rename to Lib/test/test_unicode_file_functions.py
diff --git a/Lib/test/test_pep3131.py b/Lib/test/test_unicode_identifiers.py
rename from Lib/test/test_pep3131.py
rename to Lib/test/test_unicode_identifiers.py
diff --git a/Lib/test/test_pep3120.py b/Lib/test/test_utf8source.py
rename from Lib/test/test_pep3120.py
rename to Lib/test/test_utf8source.py
diff --git a/Lib/test/test_pep380.py b/Lib/test/test_yield_from.py
rename from Lib/test/test_pep380.py
rename to Lib/test/test_yield_from.py

-- 
Repository URL: https://hg.python.org/cpython


More information about the Python-checkins mailing list